@@ -1,12 +1,12 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "pi-coding-agent" "1.2.2"
+(define-package "pi-coding-agent" "1.3.2"
   "Emacs frontend for pi coding agent."
   '((emacs         "28.1")
     (markdown-mode "2.6")
-    (transient     "0.3.7"))
+    (transient     "0.9.0"))
   :url "https://github.com/dnouri/pi-coding-agent"
-  :commit "d5adce9af546f553e24684e975f007c8c3979d90"
-  :revdesc "d5adce9af546"
+  :commit "88e20cd11f5e01b747e4fbf5142cb1cf505a9562"
+  :revdesc "v1.3.2-0-g88e20cd11f5e"
   :keywords '("ai" "llm" "ai-pair-programming" "tools")
   :authors '(("Daniel Nouri" . "daniel.nouri@gmail.com"))
   :maintainers '(("Daniel Nouri" . "daniel.nouri@gmail.com")))
